from setuptools import setup

setup(name='row_matchers',
      version='0.1',
      description='Dataset-matching function(s); simple ways for cancelling out confounding factors in datasets',
      url='http://github.com/EFraim/row_matchers',
      author='Evgeny Fraimovitch',
      author_email='evgeny@e5fraim6.com',
      license='MIT',
      py_modules=['row_matchers'],
      zip_safe=True)
